# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-25 14:14
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("timeline_logger", "0002_auto_20160624_1045"),
    ]

    operations = [
        migrations.AlterField(
            model_name="timelinelog",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
